# first function
it's function split string on symbols and push your symbols in 2 side 
#  second functon
it's function add in list 1 words or more
# third function
it's function makes a string from an array